Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(270)

Unified Diff: tests/language/src/FauxverrideTest.dart

Issue 8360022: Fix member overriding rules in VM according to latest spec. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/language/src/FauxverrideTest.dart
===================================================================
--- tests/language/src/FauxverrideTest.dart (revision 591)
+++ tests/language/src/FauxverrideTest.dart (working copy)
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Test that static members cannot be overridden.
m() {}
@@ -18,13 +18,13 @@
class Sub extends Super {
Sub() : super();
- static m() {} /// 01: compile-time error
+ static m() {} /// 01: static type error
- static var i; /// 02: compile-time error
+ static var i; /// 02: static type error
static instanceMethod() {} /// 03: compile-time error
- static i() {} /// 04: compile-time error
+ static i() {} /// 04: static type error
static var instanceMethod; /// 05: compile-time error

Powered by Google App Engine
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test that static members cannot be overridden.
+// Test that static members cannot be overridden (static type error only).
m() {}
This is Rietveld 408576698